Utility functions that provide the bulk of pwninit functionality
Modules
- Command-line option handling
Functions
- Download linker compatible with libc version
verand save to directorydir - Detect if
pathis the provided pwn binary - Detect if
pathis the provided linker - Detect if
pathis the provided libc - Same as
visit_libc(), but doesn’t do anything if no libc is found - Run
pwninitwith specified options - Set the binary executable
- Set the file at
pathexecutable - Set the detected linker executable
- Download debug symbols and apply them to a libc if it doesn’t have them already